==> jscad__array-utils-2.1.1.jar: META-INF/resources/webjars/jscad__array-utils/2.1.1/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.1.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.1.0...@jscad/array-utils@2.1.1) (2021-12-26)

**Note:** Version bump only for package @jscad/array-utils





# [2.1.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.0...@jscad/array-utils@2.1.0) (2021-04-17)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))


### Features

* **array-utils:** imported array based functionality from modeling ([#795](https://github.com/jscad/OpenJSCAD.org/issues/795)) ([f06144b](https://github.com/jscad/OpenJSCAD.org/commit/f06144be8160e325cfc6d8836b509b2904554f97))





## [2.0.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.0...@jscad/array-utils@2.0.1) (2021-04-15)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.5...@jscad/array-utils@2.0.0) (2021-04-12)

**Note:** Version bump only for package @jscad/array-utils





# [2.0.0-alpha.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.4...@jscad/array-utils@2.0.0-alpha.5) (2021-03-07)

**Note:** Version bump only for package @jscad/array-utils





# [2.0.0-alpha.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.3...@jscad/array-utils@2.0.0-alpha.4) (2020-11-07)

**Note:** Version bump only for package @jscad/array-utils





# [2.0.0-alpha.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.2...@jscad/array-utils@2.0.0-alpha.3) (2020-10-11)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0-alpha.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.1...@jscad/array-utils@2.0.0-alpha.2) (2020-09-29)

**Note:** Version bump only for package @jscad/array-utils





# [2.0.0-alpha.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.0...@jscad/array-utils@2.0.0-alpha.1) (2020-08-19)

**Note:** Version bump only for package @jscad/array-utils





# 2.0.0-alpha.0 (2020-08-13)

### Features

* **array-utils:** broke out common array functions into new package

==> jscad__array-utils-2.1.4.jar: META-INF/resources/webjars/jscad__array-utils/2.1.4/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.1.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.1.3...@jscad/array-utils@2.1.4) (2022-04-24)

**Note:** Version bump only for package @jscad/array-utils





## [2.1.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.1.2...@jscad/array-utils@2.1.3) (2022-04-03)

**Note:** Version bump only for package @jscad/array-utils





## [2.1.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.1.1...@jscad/array-utils@2.1.2) (2022-03-06)

**Note:** Version bump only for package @jscad/array-utils





## [2.1.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.1.0...@jscad/array-utils@2.1.1) (2021-12-26)

**Note:** Version bump only for package @jscad/array-utils





# [2.1.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.0...@jscad/array-utils@2.1.0) (2021-04-17)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))


### Features

* **array-utils:** imported array based functionality from modeling ([#795](https://github.com/jscad/OpenJSCAD.org/issues/795)) ([f06144b](https://github.com/jscad/OpenJSCAD.org/commit/f06144be8160e325cfc6d8836b509b2904554f97))





## [2.0.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.0...@jscad/array-utils@2.0.1) (2021-04-15)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.5...@jscad/array-utils@2.0.0) (2021-04-12)

**Note:** Version bump only for package @jscad/array-utils





# [2.0.0-alpha.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.4...@jscad/array-utils@2.0.0-alpha.5) (2021-03-07)

**Note:** Version bump only for package @jscad/array-utils





# [2.0.0-alpha.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.3...@jscad/array-utils@2.0.0-alpha.4) (2020-11-07)

**Note:** Version bump only for package @jscad/array-utils





# [2.0.0-alpha.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.2...@jscad/array-utils@2.0.0-alpha.3) (2020-10-11)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0-alpha.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.1...@jscad/array-utils@2.0.0-alpha.2) (2020-09-29)

**Note:** Version bump only for package @jscad/array-utils





# [2.0.0-alpha.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/array-utils@2.0.0-alpha.0...@jscad/array-utils@2.0.0-alpha.1) (2020-08-19)

**Note:** Version bump only for package @jscad/array-utils





# 2.0.0-alpha.0 (2020-08-13)

### Features

* **array-utils:** broke out common array functions into new package
